@@ -37,6 +37,7 @@ class AuthChallenge:
         """
         uu = uuid.uuid4()
         self.challenge = uu.bytes
+        #self.challenge = b'\x01\x02\x03'
         self.challenge_expire = time.time() + DEFAULT_CHALLENGE_EXPIRE
         return (self.challenge, self.challenge_expire,)
 
@@ -158,11 +159,10 @@ class ChallengeRetriever(Retriever):
             logg.debug('have challenge key {} {}'.format(a.hex(), self.auth[a]))
         # retrieve the challenge value
         challenge_key = source_hash(ip, challenge_user)
+        logg.debug('checking challenge {} ip {} k {}'.format(challenge_user.hex(), ip, challenge_key.hex()))
         challenge_object = self.auth[challenge_key]
-        logg.debug('checking challenge {} ip {} k {} o {}'.format(challenge_user.hex(), ip, challenge_key.hex(), challenge_object))
 
         challenge_compare = challenge_object.apply_filters(challenge_user)
-        logg.debug('checking challenge {} ip {} k {} o {}'.format(challenge_user.hex(), ip, challenge_key.hex(), challenge_object))
         challenge_correct = challenge_object.challenge
         if challenge_correct == None:
             raise ChallengeError('challenge does not exist {}'.format(challenge_user))
