@@ -18,7 +18,8 @@ class HobaFilter(http_hoba_auth.Hoba):
     """
     def filter(self, s):
         if self.challenge != s:
-            logg.error('challenge mismatch {} != {}'.format(self.challenge.hex(), s.hex()))
+            #logg.error('challenge mismatch {} != {}'.format(self.challenge.hex(), s.hex()))
+            logg.error('challenge mismatch {} != {}'.format(self.challenge, s))
             raise ValueError('challenge mismatch')
         tbs = self.to_be_signed()
         logg.debug('hoba filter {} -> {}'.format(s, tbs))
